@@ -1211,6 +1211,7 @@ static void InitVariables(void)
 	Scr.bo.do_disable_configure_notify = 0;
 	Scr.bo.do_install_root_cmap = 0;
 	Scr.bo.do_enable_flickering_qt_dialogs_workaround = 1;
+	Scr.bo.do_enable_qt_drag_n_drop_workaround = 0;
 	Scr.bo.do_enable_ewmh_iconic_state_workaround = 0;
 
 	Scr.gs.do_emulate_mwm = DEFAULT_EMULATE_MWM;
@@ -1590,6 +1591,11 @@ void StartupStuff(void)
 	}
 	exc_destroy_context(exc);
 
+	/* TA:  20091212:  If we get here, we're done restarting, so reset the
+	 * flag back to False!
+	 */
+	Restarting = False;
+
 	return;
 }
 
